<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <location filename="ui_mainwindow.h" line="623"/>
        <source>Program_Name</source>
        <translation>Ime_programa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="46"/>
        <location filename="ui_mainwindow.h" line="625"/>
        <source>Quit application</source>
        <translation>Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="49"/>
        <location filename="ui_mainwindow.h" line="627"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="55"/>
        <location filename="ui_mainwindow.h" line="629"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="87"/>
        <location filename="ui_mainwindow.h" line="632"/>
        <source>Display help </source>
        <translation>Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="90"/>
        <location filename="ui_mainwindow.h" line="634"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="96"/>
        <location filename="ui_mainwindow.h" line="636"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="112"/>
        <location filename="ui_mainwindow.h" line="638"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="169"/>
        <location filename="ui_mainwindow.h" line="640"/>
        <source>Next</source>
        <translation>Naslednji</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="194"/>
        <location filename="ui_mainwindow.h" line="645"/>
        <source>About this application</source>
        <translation>O tem programu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="197"/>
        <location filename="ui_mainwindow.h" line="647"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="203"/>
        <location filename="ui_mainwindow.h" line="649"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="219"/>
        <location filename="ui_mainwindow.h" line="651"/>
        <source>View Log</source>
        <translation>Prikaži dnevnik</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="253"/>
        <location filename="mainwindow.cpp" line="527"/>
        <location filename="mainwindow.cpp" line="550"/>
        <location filename="ui_mainwindow.h" line="652"/>
        <source>Select ISO</source>
        <translation>Izberite ISO</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="263"/>
        <location filename="ui_mainwindow.h" line="653"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Izberite ciljni USB nosilec&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="273"/>
        <location filename="ui_mainwindow.h" line="654"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Izberite ISO datoteko&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="302"/>
        <location filename="ui_mainwindow.h" line="655"/>
        <source>Advanced Options</source>
        <translation>Napredne možnosti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="320"/>
        <location filename="ui_mainwindow.h" line="656"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Napravi datotečni sistem ext4, četudi že obstaja</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="327"/>
        <location filename="ui_mainwindow.h" line="657"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Med posodabljanjem živega usb nosilca shrani originalni zagonski direktorij</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="334"/>
        <location filename="ui_mainwindow.h" line="659"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Uporabi gpt razdelke, namesto msdos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="337"/>
        <location filename="ui_mainwindow.h" line="661"/>
        <source>GPT partitioning</source>
        <translation>GPT razdeljevanje</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="344"/>
        <location filename="ui_mainwindow.h" line="662"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Posodobi (posodobi le obstoječ živi-usb)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="351"/>
        <location filename="ui_mainwindow.h" line="664"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Ne nadomesti syslinux datotek</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="354"/>
        <location filename="ui_mainwindow.h" line="666"/>
        <source>Keep syslinux files</source>
        <translation>Obdrži syslinux datoteke</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="361"/>
        <location filename="ui_mainwindow.h" line="667"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignoriraj preverjanje odstranljivosti za USB</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="368"/>
        <location filename="ui_mainwindow.h" line="668"/>
        <source>Temporarily disable automounting</source>
        <translation>Začasno izklopi samodejni priklop</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="378"/>
        <location filename="ui_mainwindow.h" line="672"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Določi zastavico pmbr_boot (ne deluje preko UEFI)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="385"/>
        <location filename="ui_mainwindow.h" line="673"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Ne uporabljajte fuseiso za priklop iso datotek</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="411"/>
        <location filename="ui_mainwindow.h" line="674"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Velikost ESP (uefi) particije:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="431"/>
        <location filename="ui_mainwindow.h" line="675"/>
        <source>Verbosity (less to more):</source>
        <translation>Podrobnosti (manj do več):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="470"/>
        <location filename="ui_mainwindow.h" line="676"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="475"/>
        <location filename="ui_mainwindow.h" line="677"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="480"/>
        <location filename="ui_mainwindow.h" line="678"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="485"/>
        <location filename="ui_mainwindow.h" line="679"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="509"/>
        <location filename="ui_mainwindow.h" line="681"/>
        <source>Make separate data partition (percent)</source>
        <translation>Ustvari ločen razdelek (odstotki)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="516"/>
        <location filename="ui_mainwindow.h" line="682"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="526"/>
        <location filename="ui_mainwindow.h" line="683"/>
        <source>Refresh drive list</source>
        <translation>Osveži seznam pogonov</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="539"/>
        <location filename="mainwindow.cpp" line="488"/>
        <location filename="ui_mainwindow.h" line="684"/>
        <source>Show advanced options</source>
        <translation>Prikaži napredne možnosti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="558"/>
        <location filename="ui_mainwindow.h" line="685"/>
        <source>Mode</source>
        <translation>Način</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="573"/>
        <location filename="ui_mainwindow.h" line="686"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation>Polna funkcionalnost - zapisljiv živi-USB</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="583"/>
        <location filename="ui_mainwindow.h" line="688"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Samo branje. Ne deluje s persistenco</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="586"/>
        <location filename="ui_mainwindow.h" line="690"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation>Posnetek diska - samo branje za živi-usb (dd)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="599"/>
        <location filename="ui_mainwindow.h" line="691"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Za distribucije, ki niso antiX/MX, uporabite način posnetek diska (dd).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="647"/>
        <location filename="ui_mainwindow.h" line="692"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="685"/>
        <location filename="ui_mainwindow.h" line="693"/>
        <source>Percent of USB-device to use:</source>
        <translation>Odstotek rabe USB naprave:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="692"/>
        <location filename="ui_mainwindow.h" line="694"/>
        <source>Label ext partition:</source>
        <translation>Oznaka ext razdelka:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="740"/>
        <location filename="ui_mainwindow.h" line="696"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Ne izvajajte ukazov, ki lahko vplivajo na usb napravo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="743"/>
        <location filename="ui_mainwindow.h" line="698"/>
        <source>Dry run (no change to system)</source>
        <translation>Suh zagon (brez sistemskih sprememb)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="750"/>
        <location filename="ui_mainwindow.h" line="700"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>kloniraj iz priklopljenega live-usb ali iso-file.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="753"/>
        <source>Clone a mounted live system</source>
        <translation>Kloniraj priklopljeni živi sistem</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="760"/>
        <location filename="ui_mainwindow.h" line="704"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Namestitev, ki se zaganja iz šifrirane particije, bo ob prvem zagonu zahtevala vnos varnostne fraze.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="763"/>
        <location filename="ui_mainwindow.h" line="706"/>
        <source>Encrypt</source>
        <translation>Šifriranje</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="770"/>
        <location filename="ui_mainwindow.h" line="707"/>
        <source>Clone running live system</source>
        <translation>Kloniraj zagnan živi sistem</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="80"/>
        <source>Confirmation</source>
        <translation>Potrditev</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="81"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation>Ciljna naprava %1 je večja od %2 GB.
Ali želite nadaljevati?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="118"/>
        <location filename="mainwindow.cpp" line="336"/>
        <location filename="mainwindow.cpp" line="472"/>
        <source>Failure</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="119"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Vir in cilj se nahajata na isti napravi. Prosimo, ponovite izbor.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="150"/>
        <source>Writing %1 using 'dd' command to /dev/%2,

Please wait until the process is completed</source>
        <translation>Zapisovanje %1 z uporabo ukaza &apos;dd&apos; na /dev/%2,

Počakajte, da se postopek zaključi</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="162"/>
        <source>Live USB Maker</source>
        <translation>Ustvarjalec za živi-usb pogon</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="333"/>
        <source>Success</source>
        <translation>Operacija je uspela</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="333"/>
        <source>LiveUSB creation successful!</source>
        <translation>ŽiviUSB je bil uspešno ustvarjen!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="336"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>ŽiviUSB ni bil uspešno ustvarjen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="394"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="394"/>
        <source>Please select a USB device to write to</source>
        <translation>Izberite USb napravo na katero naj se zapisuje</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="397"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Ta dejanje bodo uničila vse podatke na 

</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="398"/>
        <source>Do you wish to continue?</source>
        <translation>Ali želite nadaljevati?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="430"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="431"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="433"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program, ki ustvari živi-usb iz iso datoteke, drugega živega usb pogona, živega cd/dvd ploščka ali iz sistema, ki je zagnan v živo.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="436"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="437"/>
        <source>%1 License</source>
        <translation>%1 licenca</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="444"/>
        <source>%1 Help</source>
        <translation>%1 pomoč</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="452"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Izberite ISO datoteko, ki naj se zapiše na USB pogon</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="453"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation>ISO datoteke (*.iso);;Vse datoteke (*.*)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="463"/>
        <location filename="mainwindow.cpp" line="522"/>
        <source>Select Source Directory</source>
        <translation>Izberite direktorij z virom</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="473"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Nisem našel datoteke %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="494"/>
        <source>Hide advanced options</source>
        <translation>Skrij napredne možnosti</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="521"/>
        <location filename="mainwindow.cpp" line="540"/>
        <source>Select Source</source>
        <translation>Izberi vir</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="526"/>
        <location filename="mainwindow.cpp" line="548"/>
        <source>Select ISO file</source>
        <translation>Izberi ISO datoteko</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="542"/>
        <source>clone</source>
        <translation>kloniraj</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="609"/>
        <source>Could not find a log file at: </source>
        <translation>Nisem našel dnevnika v:</translation>
    </message>
    <message>
        <location filename="ui_mainwindow.h" line="702"/>
        <source>Clone an existing live system</source>
        <translation>Kloniraj obstoječ živi sistem</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="about.cpp" line="70"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="about.cpp" line="71"/>
        <location filename="about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="main.cpp" line="54"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program, ki ustvari živi-usb iz iso datoteke, drugega živega usb pogona, živega cd/dvd ploščka ali iz sistema, ki je zagnan v živo.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="58"/>
        <source>filename</source>
        <translation>ime datoteke</translation>
    </message>
    <message>
        <location filename="main.cpp" line="58"/>
        <source>Name of .iso file to open</source>
        <translation>Ime .iso datoteke za odpiranje</translation>
    </message>
    <message>
        <location filename="main.cpp" line="59"/>
        <source>[filename]</source>
        <translation>[ime datoteke]</translation>
    </message>
    <message>
        <location filename="main.cpp" line="87"/>
        <location filename="main.cpp" line="96"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="main.cpp" line="88"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Prijavljeni ste kot korenski (root) uporabnik. Odjavite se in se ponovno prijavite kot običajen uporabnik, če želite uporabljati ta program.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="96"/>
        <source>You must run this program as root.</source>
        <translation>Ta program morate zagnati korensko</translation>
    </message>
    <message>
        <location filename="main.cpp" line="111"/>
        <source>version:</source>
        <translation>različica:</translation>
    </message>
</context>
</TS>